@@ -1,7 +1,13 @@
-import fabulous.color
+try:
+    import fabulous.color
+    FABULOUS_AVAILABLE = True
+except (ValueError, ImportError):
+    FABULOUS_AVAILABLE = False
 
 import openpaperwork_core
 
+import rich.text
+
 
 def color_labels(core, labels):
     labels = [
@@ -64,6 +70,8 @@ class LabelsRenderer(object):
             out = self.parent.get_preview_output(
                 doc_id, doc_url, terminal_size, page_idx
             )
+        if not FABULOUS_AVAILABLE:
+            return out
         if page_idx != 0:
             return out
 
@@ -78,6 +86,8 @@ class LabelsRenderer(object):
             out = self.parent.get_doc_output(
                 doc_id, doc_url, terminal_size
             )
+        if not FABULOUS_AVAILABLE:
+            return out
 
         labels = self._get_labels(doc_url)
         labels = color_labels(self.core, labels)
@@ -127,11 +137,16 @@ class Plugin(openpaperwork_core.PluginBase):
             },
         ]
 
-    def print_labels(self, labels, separator='\n'):
-        labels = color_labels(self.core, labels)
-        labels = [label for (l_label, label) in labels]
-        labels = separator.join(labels)
-        print(labels)
+    def format_labels(self, labels, separator='\n'):
+        if FABULOUS_AVAILABLE:
+            labels = color_labels(self.core, labels)
+            labels = [label for (l_label, label) in labels]
+            labels = separator.join(labels)
+            labels = rich.text.Text.from_ansi(labels)
+        else:
+            labels = [label for (label, color) in labels]
+            labels = separator.join(labels)
+        return labels
 
     def doc_renderer_get(self, out):
         r = LabelsRenderer(self.core)
